package com.example;

import org.drools.KnowledgeBase;

import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderError;
import org.drools.builder.KnowledgeBuilderErrors;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.runtime.StatefulKnowledgeSession;
import org.loan.Customer;
import org.loan.Expenses;
import org.loan.Loan;



public class Test {
	public static void  main(String args[]){
		try{
			KnowledgeBase kbase = readKnowledgeBase();
			StatefulKnowledgeSession ksession = kbase.newStatefulKnowledgeSession();
			
			Loan l = new Loan();
			l.setLoanAmount(50000);
			l.setRateOfInterest(10);
			l.setPeriod(25);
			
			Customer c = new Customer();
			c.setSalary(10000);
			c.setSalaryOfSpouse(7500);
			c.setTypeOfOccupation("SelfEmployed");
			c.setOwnerOfProperty(true);
			
			Expenses e = new Expenses();
			e.setSizeOfFamily(4);
			e.setRent(8000);
			
			ksession.insert(e);			
			ksession.insert(c);
			ksession.insert(l);
			
			ksession.startProcess("loanApprovalRule");
			ksession.fireAllRules();
			
			System.out.println("Total Monthly Repayment: " +e.getMonthlyPayment());
			System.out.println("Total Expenses: " +e.getTotalExpenses());
			System.out.println("Total Income: " +c.getTotalIncome());
			System.out.println("Rating: " +c.getRating());
			
		    ksession.dispose();   
		}catch(Throwable t){
			t.printStackTrace();
		}
	}
	private static KnowledgeBase readKnowledgeBase()throws Exception{
		KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
		kbuilder.add( ResourceFactory.newUrlResource("http://localhost:8080/drools-guvnor/org.drools.guvnor.Guvnor/package/homeequity.loanApproval/LATEST"),ResourceType.PKG);
		kbuilder.add(ResourceFactory.newClassPathResource("loanApproval.rf", Test.class), ResourceType.DRF);
		KnowledgeBuilderErrors errors = kbuilder.getErrors();
		if(errors.size()>0){
			for(KnowledgeBuilderError error : errors){
				System.err.println(error);
			}
			throw new IllegalArgumentException("Could not parse knowledge.");
		}
		
		KnowledgeBase kbase = KnowledgeBaseFactory.newKnowledgeBase();
		kbase.addKnowledgePackages(kbuilder.getKnowledgePackages());
		return kbase;
	}
}
